@@ -5,6 +5,8 @@
 
    Copyright (C) 2008 OpenMoko Inc
 
+   SPDX-License-Identifier: GPL-2.0-or-later
+
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2, or (at
@@ -21,7 +23,6 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <fnmatch.h>
-#include <malloc.h>
 #include <stdlib.h>
 
 #include "opkg.h"
@@ -310,7 +311,7 @@ int opkg_install_package(const char *package_url,
     progress(&pdata, 75, progress_callback, user_data);
 
     /* unpack the package */
-    err = opkg_install_pkg(new, 0);
+    err = opkg_install_pkg(new);
 
     if (err) {
         return -1;
