@@ -6,6 +6,8 @@
    Carl D. Worth
    Copyright (C) 2001 University of Southern California
 
+   SPDX-License-Identifier: GPL-2.0-or-later
+
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2, or (at
@@ -597,6 +599,7 @@ int opkg_conf_init(void)
     pkg_dest_list_init(&opkg_config->tmp_dest_list);
     nv_pair_list_init(&opkg_config->arch_list);
     str_list_init(&opkg_config->exclude_list);
+    str_list_init(&opkg_config->ignore_recommends_list);
 
     return 0;
 }
@@ -938,6 +941,7 @@ void opkg_conf_deinit(void)
     pkg_dest_list_deinit(&opkg_config->pkg_dest_list);
     nv_pair_list_deinit(&opkg_config->arch_list);
     str_list_deinit(&opkg_config->exclude_list);
+    str_list_deinit(&opkg_config->ignore_recommends_list);
 
     if (opkg_config->verbosity >= DEBUG) {
         hash_print_stats(&opkg_config->pkg_hash);
