@@ -5,6 +5,8 @@
 
    Copyright (C) 2001 University of Southern California
 
+   SPDX-License-Identifier: GPL-2.0-or-later
+
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2, or (at
@@ -89,6 +91,7 @@ static void pkg_init(pkg_t * pkg)
     pkg->maintainer = NULL;
     pkg->section = NULL;
     pkg->description = NULL;
+    pkg->tags = NULL;
     pkg->state_want = SW_UNKNOWN;
     pkg->wanted_by = pkg_vec_alloc();
     pkg->state_flag = SF_OK;
@@ -1420,15 +1423,23 @@ static void pkg_write_filelist_helper(const char *key, void *entry_,
         struct stat file_stat;
         mode_t mode = 0;
         char *link_target = NULL;
+        size_t size;
         int unmatched_offline_root = opkg_config->offline_root
                 && !str_starts_with(key, opkg_config->offline_root);
+        char *entry = xstrdup(key);
+
+        size = strlen(entry);
+        if (size > 0 && entry[size-1] == '/')
+            entry[size-1] = '\0';
+
         if (unmatched_offline_root) {
             sprintf_alloc(&installed_file_name, "%s%s",
-                          opkg_config->offline_root, key);
+                          opkg_config->offline_root, entry);
         } else {
             // already contains root_dir as header -> ABSOLUTE
-            sprintf_alloc(&installed_file_name, "%s", key);
+            sprintf_alloc(&installed_file_name, "%s", entry);
         }
+
         if (xlstat(installed_file_name, &file_stat) == 0) {
             mode = file_stat.st_mode;
             if (S_ISLNK(mode))
@@ -1436,12 +1447,13 @@ static void pkg_write_filelist_helper(const char *key, void *entry_,
         }
 
         if (link_target)
-            fprintf(data->stream, "%s\t%#03o\t%s\n", key, (unsigned int)mode, link_target);
+            fprintf(data->stream, "%s\t%#03o\t%s\n", entry, (unsigned int)mode, link_target);
         else if (mode)
-            fprintf(data->stream, "%s\t%#03o\n", key, (unsigned int)mode);
+            fprintf(data->stream, "%s\t%#03o\n", entry, (unsigned int)mode);
         else
-            fprintf(data->stream, "%s\n", key);
+            fprintf(data->stream, "%s\n", entry);
 
+        free(entry);
         free(link_target);
         free(installed_file_name);
     }
@@ -1504,12 +1516,32 @@ int pkg_write_changed_filelists(void)
 int pkg_verify(pkg_t * pkg)
 {
     int err;
+    struct stat pkg_stat;
     char *local_sig_filename = NULL;
 
-    /* Exit if the package doesn't exist locally as the caller may be about to
-     * download it. */
-    if (!file_exists(pkg->local_filename))
-        return 1;
+    err = stat(pkg->local_filename, &pkg_stat);
+    if (err) {
+        if (errno == ENOENT) {
+            /* Exit with soft error 1 if the package doesn't exist.
+             * This allows the caller to download it without nasty
+             * messages in the error log.
+             */
+            return 1;
+        }
+        else {
+            opkg_msg(ERROR, "Failed to stat %s: %s\n",
+                pkg->local_filename, strerror(errno));
+            goto fail;
+        }
+    }
+
+    /* Check size to mitigate hash collisions. */
+    if (pkg_stat.st_size < 1 || pkg_stat.st_size != pkg->size) {
+        err = -1;
+        opkg_msg(ERROR, "File size mismatch: %s is %lld bytes, expecting %lu bytes\n",
+            pkg->local_filename, (long long int)pkg_stat.st_size, pkg->size);
+        goto fail;
+    }
 
 #ifdef HAVE_SHA256
     if (pkg->sha256sum) {
