@@ -7,6 +7,8 @@
    Carl D. Worth
    Copyright 2001 University of Southern California
 
+   SPDX-License-Identifier: GPL-2.0-or-later
+
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2, or (at
@@ -51,6 +53,7 @@ enum {
     ARGS_OPT_ADD_DEST,
     ARGS_OPT_SIZE,
     ARGS_OPT_ADD_EXCLUDE,
+    ARGS_OPT_ADD_IGNORE_RECOMMENDS,
     ARGS_OPT_NOACTION,
     ARGS_OPT_DOWNLOAD_ONLY,
     ARGS_OPT_NODEPS,
@@ -112,6 +115,7 @@ static struct option long_options[] = {
     {"add-dest", 1, 0, ARGS_OPT_ADD_DEST},
     {"size", 0, 0, ARGS_OPT_SIZE},
     {"add-exclude", 1, 0, ARGS_OPT_ADD_EXCLUDE},
+    {"add-ignore-recommends", 1, 0, ARGS_OPT_ADD_IGNORE_RECOMMENDS},
     {"test", 0, 0, ARGS_OPT_NOACTION},
     {"tmp-dir", 1, 0, 't'},
     {"tmp_dir", 1, 0, 't'},
@@ -234,6 +238,9 @@ static int args_parse(int argc, char *argv[])
         case ARGS_OPT_ADD_EXCLUDE:
             str_list_append(&opkg_config->exclude_list, optarg);
             break;
+        case ARGS_OPT_ADD_IGNORE_RECOMMENDS:
+            str_list_append(&opkg_config->ignore_recommends_list, optarg);
+            break;
         case ARGS_OPT_SIZE:
             opkg_config->size = 1;
             break;
@@ -318,7 +325,9 @@ static void usage()
     printf("\twhatprovides [-A] [pkgname|glob]+\n");
     printf("\twhatconflicts [-A] [pkgname|glob]+\n");
     printf("\twhatreplaces [-A] [pkgname|glob]+\n");
-
+    printf("\tverify [pkg|glob]               Verifies the intrgrity of <pkg>, or all packages if omitted by\n");
+    printf("\t                                comparing the md5sum of each file with the information stored\n");
+    printf("\t                                on the opkg metadata database");
     printf("\nOptions:\n");
     printf("\t-A                              Query all packages not just those installed\n");
     printf("\t-V[<level>]                     Set verbosity level to <level>.\n");
@@ -343,6 +352,7 @@ static void usage()
     printf("\t--add-dest <name>:<path>        Register destination with given path\n");
     printf("\t--add-arch <arch>:<prio>        Register architecture with given priority\n");
     printf("\t--add-exclude <name>            Register package to be excluded from install\n");
+    printf("\t--add-ignore-recommends <name>  Register package to be ignored as a recomendee\n");
     printf("\t--prefer-arch-to-version        Use the architecture priority package rather\n");
     printf("\t                                than the higher version one if more\n");
     printf("\t                                than one candidate is found.\n");
@@ -414,7 +424,8 @@ int main(int argc, char *argv[])
         || !strcmp(cmd_name, "print-installation-architecture")
         || !strcmp(cmd_name, "print_installation_architecture")
         || !strcmp(cmd_name, "compare_versions")
-        || !strcmp(cmd_name, "compare-versions");
+        || !strcmp(cmd_name, "compare-versions")
+        || !strcmp(cmd_name, "clean");
 
     noreadfeedsfile = !strcmp(cmd_name, "flag")
         || !strcmp(cmd_name, "configure")
@@ -425,7 +436,8 @@ int main(int argc, char *argv[])
         || !strcmp(cmd_name, "list-installed")
         || !strcmp(cmd_name, "list_changed_conffiles")
         || !strcmp(cmd_name, "list-changed-conffiles")
-        || !strcmp(cmd_name, "status");
+        || !strcmp(cmd_name, "status")
+        || !strcmp(cmd_name, "clean");
 
     noloadconf = !strcmp(cmd_name, "compare_versions")
         || !strcmp(cmd_name, "compare-versions");
