@@ -1,4 +1,5 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
+# SPDX-License-Identifier: GPL-2.0-only
 #
 # Install a package 'a' which depends on a second package 'b'. Check that both
 # are installed, that package 'a' does not report as automatically installed but
@@ -29,3 +30,11 @@ if opkgcl.is_autoinstalled("a"):
 	opk.fail("Package 'a' explicitly installed by reports as auto installed.")
 if not opkgcl.is_autoinstalled("b"):
 	opk.fail("Package 'b' installed as a dependency but does not report as auto installed.")
+
+# Check that trying to remove 'b' fails and doesn't change the system (issue 9862)
+if not opkgcl.remove("b"):
+        opk.fail("Package 'b' should not be allowed to be uninstalled")
+if not opkgcl.is_installed("a"):
+        opk.fail("Package 'a' was incorrectly uninstalled")
+if not opkgcl.is_installed("b"):
+        opk.fail("Package 'b' was incorrectly uninstalled")
